==> profile-watcher-0.0.1.tar.gz: profile-watcher-0.0.1/watcher/watcher.py <==
#!/usr/bin/python
# A python library that provides update when something changes in social profiles.
# Copyright (C) 2021 Shubhendra Kushwaha
# @TheShubhendra shubhendrakushwaha94@gmail.com
# This file is a part of profile-watcher <https://github.com/TheShubhendra/profile-watcher>.
#
# profile-watcher is a free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# profile-watcher is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with profile-watcher.  If not, see <http://www.gnu.org/licenses/>.
from queue import Queue
from apscheduler.schedulers.background import BackgroundScheduler
from profiles.quora import User
from .update import Update
from .examiner import Examiner


class Watcher:
    def __init__(self):
        self.scheduler = BackgroundScheduler()
        self.updateQueue = Queue()
        self.examiner = Examiner(self)

    def add_quora(self, username):
        def get_quora(username):
            user = User(username)
            self.updateQueue.put(Update("quora", user))

        self.scheduler.add_job(get_quora, "interval", seconds=5, args=(username,))

    def start(self):
        self.scheduler.start()
        self.examiner.start()

==> profile-watcher-0.0.2.tar.gz: profile-watcher-0.0.2/watcher/watcher.py <==
#!/usr/bin/python
# A python library that provides update when something changes in social profiles.
# Copyright (C) 2021 Shubhendra Kushwaha
# @TheShubhendra shubhendrakushwaha94@gmail.com
# This file is a part of profile-watcher <https://github.com/TheShubhendra/profile-watcher>.
#
# profile-watcher is a free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# profile-watcher is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with profile-watcher.  If not, see <http://www.gnu.org/licenses/>.
import asyncio
from quora import User
from .updaters import Quora
from .dispatcher import Dispatcher
from threading import Thread


class Watcher:
    def __init__(self):
        self.eventQueue = asyncio.Queue()
        self.updaters = []
        self.dispatcher = Dispatcher(self.eventQueue)

    def add_quora(self, username):
        updater = Quora(username, self)
        self.updaters.append(updater)

    async def start(self):
        tasks = []
        tasks.append(asyncio.create_task(self.dispatcher.listen()))
        for updater in self.updaters:
            tasks.append(asyncio.create_task(updater.start()))
        [await asyncio.gather(task) for task in tasks]
